@@ -466,12 +466,7 @@ static verdict ttp64_alloc_skb(struct xlation *state)
 		goto revert;
 	}
 
-	/* https://github.com/NICMx/Jool/issues/289 */
-#if LINUX_VERSION_AT_LEAST(5, 4, 0, 9, 0)
-	nf_reset_ct(out);
-#else
-	nf_reset(out);
-#endif
+	skb_cleanup_copy(out);
 
 	/* Remove outer l3 and l4 headers from the copy. */
 	skb_pull(out, pkt_hdrs_len(in));
