@@ -88,7 +88,6 @@ static struct joolnl_stat_metadata const jstat_metadatas[] = {
 	DEFINE_STAT(JSTAT_ICMP6ERR_FAILURE, "ICMPv6 errors (created by Jool, not translated) that could not be sent."),
 	DEFINE_STAT(JSTAT_ICMP4ERR_SUCCESS, "ICMPv4 errors (created by Jool, not translated) sent successfully."),
 	DEFINE_STAT(JSTAT_ICMP4ERR_FAILURE, "ICMPv4 errors (created by Jool, not translated) that could not be sent."),
-	DEFINE_STAT(JSTAT_ICMPEXT_SMALL, "Illegal ICMP header length. (Inner packet has less than 128 bytes.)"),
 	DEFINE_STAT(JSTAT_ICMPEXT_BIG, "Illegal ICMP header length. (Exceeds available payload in packet.)"),
 	DEFINE_STAT(JSTAT_UNKNOWN, TC "Programming error found. The module recovered, but the packet was dropped."),
 	DEFINE_STAT(JSTAT_PADDING, "Dummy; ignore this one."),
@@ -177,6 +176,7 @@ struct jool_result joolnl_stats_foreach(struct joolnl_socket *sk,
 	qargs.cb = cb;
 	qargs.args = args;
 	qargs.done = true;
+	qargs.last = 0;
 
 	do {
 		result = joolnl_alloc_msg(sk, iname, JNLOP_STATS_FOREACH, 0, &msg);
